<?php 
/**
 * @file
 * Bar chart displaying information about sources
 */
$plugin = array(
  'single' => TRUE,  
  'title' => t('Petitions: Page Performance Chart'),  
  'description' => t('Displays a chart showing the performance of various petition pages.'), 
  'category' => t('CRM Core Petition'),
  'admin info' => 'crm_core_petition_petition_page_chart_info', 
  'edit form' => 'crm_core_petition_petition_page_chart_form',
  'render callback' => 'crm_core_petition_petition_page_chart', 
  'defaults' => array(
    'height' => variable_get('crm_core_petition_default_height', '250'),
    'color_series' => variable_get('crm_core_petition_series_colors', ''),
    'display_labels' => variable_get('crm_core_petition_display_labels', 0),
    'chart_color' => variable_get('crm_core_petition_chart_color', ''),
    'column_width' => variable_get('crm_core_petition_default_colum_width', ''),
    'include_legend' => '0',
  ),
  'all contexts' => TRUE, 
);

/**
 * admin info
 */
function crm_core_petition_petition_page_chart_info($subtype, $conf, $contexts){
  $block = new stdClass;
  $block->title = t('Petitions: Source Chart');
  $block->content = t('Displays a chart showing sources for all signature activity.');
  return $block;
}

/**
 * Settings form
 */
function crm_core_petition_petition_page_chart_form ($form, &$form_state){
  $conf = $form_state['conf'];

  $form['include_legend'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display a legend'),
    '#description' => t('Check this box to include a legend in your chart.'),
    '#default_value' => !empty($conf['include_legend']) ? $conf['include_legend'] : '0',
    '#return_value' => 1,
  );

  // display settings
  $form['display_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Display settings'),
    '#weight' => 5,
    '#collapsible' => FALSE,
  );

  // height
  $form['display_settings']['height'] = array(
    '#type' => 'textfield',
    '#title' => t('Height'),
    '#description' => t('Please enter the height of the chart, as an integer.'),
    '#default_value' => !empty($conf['height']) ? $conf['height'] : '',
  );

  $form['display_settings']['column_width'] = array(
    '#type' => 'textfield',
    '#title' => t('Column width'),
    '#description' => t('Please enter the default width of columns, as a decimal. Example: 0.8.'),
    '#default_value' => !empty($conf['column_width']) ? $conf['column_width'] : '',
  );

  // display labels
  $form['display_labels'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display labels'),
    '#description' => t('Check this box to display labels for every region on your chart.'),
    '#default_value' => !empty($conf['display_labels']) ? $conf['display_labels'] : '0',
    '#return_value' => 1,
  );

  // chart color
  $form['display_settings']['chart_color'] = array(
    '#type' => 'textfield',
    '#title' => t('Chart color'),
    '#description' => t('Please enter the color to use for the line in valid #RRGGBB or rgba format. Leave blank to use the default color.'),
    '#default_value' => !empty($conf['chart_color']) ? $conf['chart_color'] : '',
  );

  // color series
  $form['display_settings']['color_series'] = array(
    '#type' => 'textarea',
    '#title' => t('Color series'),
    '#description' => t('Please enter the colors to use for the data series in valid #RRGGBB or rgba format. Please separate each value with a new line. Leave blank to use the default colors.'),
    '#default_value' => !empty($conf['color_series']) ? $conf['color_series'] : '',
  );

  return $form;
}

/**
 * Validation handler for settings form.
 */
function crm_core_petition_petition_page_chart_form_validate ($form, &$form_state){

  // height
  if(!is_numeric($form_state['values']['height'])){
    form_set_error('height', t('The height of the chart must be entered as a number (i.e. 200).'));
  }

}

/**
 * Submit handler for settings form.
 */
function crm_core_petition_petition_page_chart_form_submit ($form, &$form_state){
  // legend
  $form_state['conf']['include_legend'] = $form_state['values']['include_legend'];

  // height
  $form_state['conf']['height'] = $form_state['values']['height'];
  $form_state['conf']['column_width'] = $form_state['values']['column_width'];

  // colors
  $form_state['conf']['color_series'] = $form_state['values']['color_series'];

  // display labels
  $form_state['conf']['display_labels'] = $form_state['values']['display_labels'];
  $form_state['conf']['chart_color'] = $form_state['values']['chart_color'];
}

/**
 * Render callback
 */
function crm_core_petition_petition_page_chart($subtype, $conf, $panel_args, $context = NULL){

  // create some default containers for data
  $sourceData = array();
  $pageLabels = array();
  $items = array();
  $count = 0;
  
  // select all the sources for petition signatures
  $pages = db_query("
  	SELECT 
  		COUNT(fdpp.entity_id) AS amount, 
  		fdpp.field_cmcp_petition_page_target_id AS source,
  		n.title AS page
		FROM {field_data_field_cmcp_petition_page} fdpp
  		JOIN {node} n
  		ON fdpp.field_cmcp_petition_page_target_id = n.nid
  	GROUP BY page
		ORDER BY page;");
  
  // prepare the data
  foreach ($pages as $page) {
    $item = new flotData(array(array($count, $page->amount)));
    $sourceLabels[] = array($count, $page->page);
    $item->label = $page->page;
    $sourceData[] = $item;
    $count++;
  }

  // create a new bar chart
  $options = new flotStyleBar();

  // add labels to the x-axis
  $options->xaxis = new stdClass();
  $options->xaxis->ticks = $sourceLabels;
  $options->xaxis->autoscaleMargin = .10;

  // need to add a bar width
  $options->bars = new stdClass();
  if($conf['column_width'] !== '' && $conf['column_width'] !== 0){
    $options->bars->barWidth = (float)$conf['column_width'];
  }
  $options->bars->align = 'center';
  $options->bars->lineWidth = 2;

  /* grid */
  $options->grid->borderWidth = 2;
  $options->grid->labelMargin = 8;
  if($conf['chart_color'] !== ''){
    $options->grid->backgroundColor = $conf['chart_color'];
  }
  $options->grid->minBorderMargin = 12;

  /* colors */
  if($conf['color_series'] !== ''){
    $options->colors = explode("\n",$conf['color_series']);
  }

  $content = theme('flot_graph', array(
    'data' => $sourceData,
    'options' => $options,
    'element' => array(
      'style' => 'width: 100%; height: ' . (int)$conf['height'] . 'px;',
    ),
    'legend'	=> ($conf['include_legend'] === 1) ? TRUE : FALSE,
  ));
  

  $block = new stdClass();
  $block->title = '';
  $block->content = $content;
          
  return $block;
}
