<?php

/**
 * @file
 * Line chart displaying signature activity.
 */

// Plugin definition.
$plugin = array(
  'single' => TRUE,
  'title' => t('Petitions: Source Summary Signature History'),
  'description' => t('Displays a line chart showing signature history.'),
  'category' => t('CRM Core Petition'),
  'edit form' => 'cmcp_source_signature_history_form',
  'render callback' => 'cmcp_source_signature_history_render',
  'admin info' => 'cmcp_source_signature_history_admin_info',
  'defaults' => array(
    'text' => '',
  ),
  'all contexts' => TRUE,
);

/**
 * admin info
 */
function cmcp_source_signature_history_admin_info($subtype, $conf, $contexts) {
  $block = new stdClass;
  $block->title = t('Petitions: Source Summary Signature History');
  $block->content = t('Displays a line chart showing signature history over a specified period. Defaults to 90 days in the past.');
  return $block;
}

/**
 * Settings form.
 */
function cmcp_source_signature_history_form($form, &$form_state) {

  // this widget should allow users to set the timeframe for performance
  $conf = $form_state['conf'];
  $form['time_period'] = array(
    '#type' => 'textfield',
    '#title' => t('Time Period'),
    '#description' => t('Enter the number of days to report back on for this widget. If no value is provided, defaults to 90.'),
    '#default_value' => !empty($conf['time_period']) ? $conf['time_period'] : '90',
  );
  return $form;
}

/**
 * Submit handler for settings form.
 */
function cmcp_source_signature_history_form_submit($form, &$form_state) {
  $form_state['conf']['time_period'] = $form_state['values']['time_period'];
}

/**
 * Render callback.
 */
function cmcp_source_signature_history_render($subtype, $conf, $panel_args, $context = NULL) {

  // get the number of days to report back
  $days = $conf['time_period'];

  $source = $panel_args[0];

  // run the query
  $dates = db_query("
  SELECT COUNT(fdd.entity_id) AS amount,
  	UNIX_TIMESTAMP(field_cmcp_received_date_value) AS timestamp,
  	DATE_FORMAT(field_cmcp_received_date_value, '%b %e') AS rdate,
  	DATE_FORMAT(field_cmcp_received_date_value, '%j') AS doy
  	FROM {field_data_field_cmcp_received_date} fdd
  	JOIN {field_data_field_cmcp_source} fds
  	  ON fds.entity_id = fdd.entity_id
  	WHERE fdd.field_cmcp_received_date_value > SUBDATE(NOW(), INTERVAL $days DAY)
  	  AND fdd.field_cmcp_received_date_value != ''
  	  AND fdd.field_cmcp_received_date_value IS NOT NULL
  	  AND fds.field_cmcp_source_value = :source
  	GROUP BY rdate, doy 
  	ORDER BY timestamp, rdate, doy DESC;
	", array(':source' => $source));

  // normalize the query for zero values, avoid big arcs
  $dateItem = array();
  $lastDate = '';
  $lastDateTS = '';
  $seriesLabels = array();
  
  foreach ($dates as $date) {
    // check if today is greater than lastdate
    if (($date->doy - $lastDate) > 1 && $lastDate != '') {
      // insert some zero values for yesterday and the day after lastdate
      $dateItem[] = array($lastDateTS * 1000 + 86400 * 1000, 0);
      $seriesLabels[] = '---';
      // add one for the day before the current record as well
      $dateItem[] = array(($date->timestamp * 1000) - 86400 * 1000, 0);
      $seriesLabels[] = '---';
    }

    // add the date
    // $dateItem[] = array($date->timestamp*1000, $date->amount);
    $dateItem[] = array($date->timestamp * 1000, $date->amount);

    // record a label
    $seriesLabels[] = $date->rdate . '<br>' . $date->amount;

    // set lastdate
    $lastDate = $date->doy;
    $lastDateTS = $date->timestamp;
  }
  
  // draw the chart
  $dateData[] = new flotData($dateItem);

  $options = new flotStyleLine();
  $options->series->seriesLabels = $seriesLabels;
  $options->series->lines = new stdClass();
  $options->series->lines->show = true;
  $options->series->lines->fill = TRUE;
  $options->series->lines->lineWidth = 4;
  $options->series->lines->fillColor = array(
    'colors' => array(
			"rgba(49, 81, 189, 0.4)",
			"rgba(49, 81, 189, 0)",
    )
  );
  
  /* points */
  $options->series->points = new stdClass();
  $options->series->points->show = TRUE;
  $options->series->points->fill = TRUE;
  $options->series->points->radius = 4;
  $options->series->points->lineWidth = 2;

  /* grid */
  $options->grid->borderWidth = 2;
  $options->grid->labelMargin = 8;
  $options->grid->backgroundColor = "rgba(255, 255, 255, 1)";
  
  /* xaxis */
  $options->xaxis = new stdClass();
  $options->xaxis->mode = "time";
  $options->xaxis->ticks = 7;
  
  /* yaxis */
  $options->yaxis = new stdClass();
  $options->yaxis->min = 0;
      
  /* colors */
  $options->colors = array(
		"rgba(49, 81, 189, 1)",
  );
  
  $content = theme('flot_graph', array(
  	'data' => $dateData, 
  	'options'	=> $options,
    'element' => array(
    	'style' => 'width: 100%; height: 260px;',
    ),
  ));  
  
  $block = new stdClass();

  $block->title = t('Signature History');
  $block->content = $content;

  return $block;
}

